==> klayout-0.10.tar.gz: klayout-0.10/src/layRubberBox.cc <==

/*

  KLayout Layout Viewer
  Copyright (C) 2006 Matthias Koefferlein

  This program is free software; you can redistribute it and/or modify
  it under the terms of the GNU General Public License as published by
  the Free Software Foundation; either version 2 of the License, or
  (at your option) any later version.

  This program is distributed in the hope that it will be useful,
  but WITHOUT ANY WARRANTY; without even the implied warranty of
  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  GNU General Public License for more details.

  You should have received a copy of the GNU General Public License
  along with this program; if not, write to the Free Software
  Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA

*/



#include "layRubberBox.h"
#include "layRenderer.h"

namespace lay
{

// -------------------------------------------------------------
//  RubberBox implementation

RubberBox::RubberBox (lay::ViewObjectCanvas *canvas, unsigned int color, const db::DPoint &p1, const db::DPoint &p2)
  : lay::ViewObject (canvas, false /*not static*/), 
    m_p1 (p1), m_p2 (p2), m_color (color), m_stipple (0)
{ }

void 
RubberBox::set_color (unsigned int color)
{
  if (m_color != color) {
    m_color = color;
    redraw ();
  }
}

void 
RubberBox::set_stipple (unsigned int s)
{
  if (m_stipple != s) {
    m_stipple = s;
    redraw ();
  }
}

void 
RubberBox::render ()
{ 
  lay::Renderer r;
  r.reserve_edges (4);
  r.insert (canvas ()->trans () * db::DBox (m_p1, m_p2));
  lay::Bitmap *bitmap = canvas ()->bitmap (lay::ViewOp (m_color, lay::ViewOp::Copy, m_stipple));
  if (bitmap) {
    r.render_contour (*bitmap);
  }
}

void
RubberBox::set_points (const db::DPoint &p1, const db::DPoint &p2)
{ 
  if (m_p1 != p1 || m_p2 != p2) {
    m_p1 = p1;
    m_p2 = p2;
    redraw ();
  }
}

}

==> klayout-0.15.tar.gz: klayout-0.15/src/layRubberBox.cc <==

/*

  KLayout Layout Viewer
  Copyright (C) 2006-2007 Matthias Koefferlein

  This program is free software; you can redistribute it and/or modify
  it under the terms of the GNU General Public License as published by
  the Free Software Foundation; either version 2 of the License, or
  (at your option) any later version.

  This program is distributed in the hope that it will be useful,
  but WITHOUT ANY WARRANTY; without even the implied warranty of
  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  GNU General Public License for more details.

  You should have received a copy of the GNU General Public License
  along with this program; if not, write to the Free Software
  Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA

*/



#include "layViewport.h"
#include "layRubberBox.h"
#include "layRenderer.h"

namespace lay
{

// -------------------------------------------------------------
//  RubberBox implementation

RubberBox::RubberBox (lay::ViewObjectWidget *widget, unsigned int color, const db::DPoint &p1, const db::DPoint &p2)
  : lay::ViewObject (widget, false /*not static*/), 
    m_p1 (p1), m_p2 (p2), m_color (color), m_stipple (0)
{ }

void 
RubberBox::set_color (unsigned int color)
{
  if (m_color != color) {
    m_color = color;
    redraw ();
  }
}

void 
RubberBox::set_stipple (unsigned int s)
{
  if (m_stipple != s) {
    m_stipple = s;
    redraw ();
  }
}

void 
RubberBox::render (const Viewport &vp, ViewObjectCanvas &canvas)
{ 
  lay::Renderer r;
  r.reserve_edges (4);
  r.insert (vp.trans () * db::DBox (m_p1, m_p2));
  lay::Bitmap *bitmap = canvas.bitmap (lay::ViewOp (m_color, lay::ViewOp::Copy, m_stipple), vp.width (), vp.height ());
  if (bitmap) {
    r.render_contour (*bitmap);
  }
}

void
RubberBox::set_points (const db::DPoint &p1, const db::DPoint &p2)
{ 
  if (m_p1 != p1 || m_p2 != p2) {
    m_p1 = p1;
    m_p2 = p2;
    redraw ();
  }
}

}
